@@ -231,7 +231,8 @@ ArrayToNc <- function(arrays, file_path) {
   if (is.array(arrays)) {
     arrays <- list(arrays)
   }
-  if (any(!sapply(arrays, function(x) is.array(x) && (is.numeric(x) || is.logical(x))))) {
+  if (any(!sapply(arrays, function(x) is.array(x) &&
+                  (is.numeric(x) || is.logical(x) || is.character(x))))) {
     stop("The parameter 'arrays' must be one or a list of numeric or logical arrays.")
   }
   # Check parameter file_path.
@@ -444,6 +445,7 @@ ArrayToNc <- function(arrays, file_path) {
           var_info[['prec']] <- 'short'
         } else if (typeof(arrays[[i]]) == 'character') {
           var_info[['prec']] <- 'char'
+          attr(arrays[[i]], "variables")[[var_info[['name']]]] <- list(prec = 'char')
         } else if (typeof(arrays[[i]]) == 'integer') {
           var_info[['prec']] <- 'integer'
         } else {
@@ -455,6 +457,14 @@ ArrayToNc <- function(arrays, file_path) {
         }
         var_info[['prec']] <- var_info[['prec']][1]
       }
+
+      if (var_info[['prec']] == 'char') {
+        dimnchar_name <- paste0(var_info[['name']], "_length")
+        dimnchar <- ncdim_def(dimnchar_name, "", 1:max(sapply(arrays[[i]], nchar)),
+                              create_dimvar = FALSE)
+        defined_dims[[dimnchar_name]] <- dimnchar
+        var_built_dims <- c(dimnchar_name, var_built_dims)
+      }
       new_var <- list(ncvar_def(var_info[['name']], var_info[['units']], 
                                 defined_dims[var_built_dims], 
                                 var_info[['missval']], 
@@ -502,14 +512,17 @@ ArrayToNc <- function(arrays, file_path) {
         }
         add_offset <- var_info[['addOffset']][1]
       }
-      if (is.null(var_dim)) {
+      if (!is.null(var_info[['prec']]) && var_info[['prec']] == 'char') {
+        ncvar_put(ncdf_object, defined_vars[[var_counter]]$name,
+                  arrays[[i]])
+      } else if (is.null(var_dim)) {
         if (scale_factor != 1 || add_offset != 0) {
           ncvar_put(ncdf_object, defined_vars[[var_counter]]$name, 
                     (arrays[[i]] - add_offset) / scale_factor, 
-                    count = dim(arrays[[i]]))
+                     count = dim(arrays[[i]]))
         } else {
           ncvar_put(ncdf_object, defined_vars[[var_counter]]$name, 
-                    arrays[[i]], 
+                    arrays[[i]],
                     count = dim(arrays[[i]]))
         }
       } else {
